@@ -7,7 +7,7 @@
 # Like what you see? Join us!
 # https://www.univention.com/about-us/careers/vacancies/
 #
-# Copyright 2004-2023 Univention GmbH
+# Copyright 2004-2024 Univention GmbH
 #
 # https://www.univention.de/
 #
@@ -65,7 +65,7 @@ import listener
 
 
 description = 'LDAP Replica Node replication'
-filter = '(objectClass=*)'  # default filter - may be overwritten later
+filter = '(!(objectClass=lock))'  # default filter - may be overwritten later
 modrdn = '1'
 priority = 0.0
 
